You are viewing a plain text version of this content. The canonical link for it is here.
Posted to cvs@cocoon.apache.org by jo...@apache.org on 2006/10/14 19:23:56 UTC

svn commit: r463984 - in /cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl: src/main/java/org/apache/cocoon/components/validation/jaxp/JaxpSchemaParser.java status.xml

Author: joerg
Date: Sat Oct 14 10:23:56 2006
New Revision: 463984

URL: http://svn.apache.org/viewvc?view=rev&rev=463984
Log:
fixed COCOON-1878: Replaced references to constant declarations in javax.xml.XMLConstants, which are not in the official API.

Added:
    cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/status.xml   (with props)
Modified:
    cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/src/main/java/org/apache/cocoon/components/validation/jaxp/JaxpSchemaParser.java

Modified: cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/src/main/java/org/apache/cocoon/components/validation/jaxp/JaxpSchemaParser.java
URL: http://svn.apache.org/viewvc/cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/src/main/java/org/apache/cocoon/components/validation/jaxp/JaxpSchemaParser.java?view=diff&rev=463984&r1=463983&r2=463984
==============================================================================
--- cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/status.xml (added)
+++ cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/status.xml Sat Oct 14 10:23:56 2006
@@ -0,0 +1,76 @@
+<?xml version="1.0"?>
+<!--
+  Licensed to the Apache Software Foundation (ASF) under one or more
+  contributor license agreements.  See the NOTICE file distributed with
+  this work for additional information regarding copyright ownership.
+  The ASF licenses this file to You under the Apache License, Version 2.0
+  (the "License"); you may not use this file except in compliance with
+  the License.  You may obtain a copy of the License at
+
+      http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+-->
+<!DOCTYPE status [
+<!ELEMENT status (developers?, todo?, changes)>
+<!ELEMENT developers (person+)>
+<!ELEMENT person EMPTY>
+<!ATTLIST person
+  name CDATA #REQUIRED
+  email CDATA #REQUIRED
+  id CDATA #REQUIRED
+>
+<!ELEMENT todo (actions+)>
+<!ELEMENT actions (action+)>
+<!ATTLIST actions
+  priority (high | medium | low) #REQUIRED
+>
+<!ELEMENT changes (release+)>
+<!ELEMENT release (action*)>
+<!ATTLIST release
+  version CDATA #REQUIRED
+  date CDATA #REQUIRED
+>
+<!ELEMENT action (#PCDATA | link | br | code | ul | strong)*>
+<!ATTLIST action
+  context (build | code | docs) #IMPLIED
+  assigned-to CDATA #IMPLIED
+  dev CDATA #IMPLIED
+  type (add | fix | remove | update) #IMPLIED
+  fixes-bug CDATA #IMPLIED
+  due-to CDATA #IMPLIED
+  due-to-email CDATA #IMPLIED
+>
+<!ELEMENT code (#PCDATA)>
+<!ELEMENT br EMPTY>
+<!ELEMENT strong (#PCDATA)>
+<!ELEMENT link (#PCDATA)>
+<!ATTLIST link
+  href CDATA #REQUIRED
+>
+<!ELEMENT ul (li)+>
+<!ELEMENT li (#PCDATA | link | br | code | ul)*>
+<!ENTITY eacute           "&#x000E9;">
+<!ENTITY ouml             "&#x000F6;">
+<!ENTITY uuml             "&#x000FC;">
+<!ENTITY ccedil           "&#x000E7;">
+]>
+
+<!-- SVN $Id: status.xml 454483 2006-10-09 20:09:25Z joerg $ -->
+
+<status>
+ <!-- The following list contains the changes since the latest 2.1.x version. -->
+ <changes>
+  <release version="@version@" date="@date@">
+    <action dev="JH" type="fix" fixes-bug="COCOON-1878">
+      Replaced references to constant declarations in
+      <code>javax.xml.XMLConstants</code>, which are not in the official API.
+    </action>
+  </release>
+ </changes>
+
+</status>

Propchange: cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/status.xml
------------------------------------------------------------------------------
    svn:eol-style = native
--- cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/src/main/java/org/apache/cocoon/components/validation/jaxp/JaxpSchemaParser.java (original)
+++ cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/src/main/java/org/apache/cocoon/components/validation/jaxp/JaxpSchemaParser.java Sat Oct 14 10:23:56 2006
@@ -20,7 +20,6 @@
 import java.util.HashSet;
 import java.util.Set;
 
-import javax.xml.XMLConstants;
 import javax.xml.transform.sax.SAXSource;
 import javax.xml.validation.SchemaFactory;
 
@@ -66,9 +65,9 @@
      * instance.</p>
      * 
      * <p>Grammars will be automatically detected if the {@link SchemaFactory}
      * supports one of the {@link XMLConstants#RELAXNG_NS_URI RELAX-NG} grammar,
      * {@link XMLConstants#W3C_XML_SCHEMA_NS_URI XML-Schema} grammar, or the
      * {@link XMLConstants#XML_DTD_NS_URI XML-DTD} grammar.</p>
      * 
      * <p>If the factory is known to support different grammars, the default
      * detection can be overridden specifying in the configuration something similar
@@ -112,13 +111,13 @@
         } else {
 
             /* Attempt to detect the languages directly using the JAXP factory */
-            if (fact.isSchemaLanguageSupported(XMLConstants.W3C_XML_SCHEMA_NS_URI)) {
+            if (fact.isSchemaLanguageSupported(Validator.GRAMMAR_XML_SCHEMA)) {
                 grammars.add(Validator.GRAMMAR_XML_SCHEMA);
             }
-            if (fact.isSchemaLanguageSupported(XMLConstants.RELAXNG_NS_URI)) {
+            if (fact.isSchemaLanguageSupported(Validator.GRAMMAR_RELAX_NG)) {
                 grammars.add(Validator.GRAMMAR_RELAX_NG);
             }
-            if (fact.isSchemaLanguageSupported(XMLConstants.XML_DTD_NS_URI)) {
+            if (fact.isSchemaLanguageSupported(Validator.GRAMMAR_XML_DTD)) {
                 grammars.add(Validator.GRAMMAR_XML_DTD);
             }
         }
@@ -66,9 +65,9 @@
      * 
      * <p>Grammars will be automatically detected if the {@link SchemaFactory}
-     * supports one of the {@link XMLConstants#RELAXNG_NS_URI RELAX-NG} grammar,
-     * {@link XMLConstants#W3C_XML_SCHEMA_NS_URI XML-Schema} grammar, or the
-     * {@link XMLConstants#XML_DTD_NS_URI XML-DTD} grammar.</p>
+     * supports one of the {@link Validator.GRAMMAR_RELAX_NG RELAX-NG} grammar,
+     * {@link Validator.GRAMMAR_XML_SCHEMA XML-Schema} grammar, or the
+     * {@link Validator.GRAMMAR_XML_DTD XML-DTD} grammar.</p>
      * 
      * <p>If the factory is known to support different grammars, the default

Added: cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/status.xml
URL: http://svn.apache.org/viewvc/cocoon/trunk/blocks/cocoon-validation/cocoon-validation-impl/status.xml?view=auto&rev=463984
==============================================================================